/*
    Copyright (C) 2004 Adam Olsen

	This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <sqlitem/sqlitemanager.hpp>
#include <sqlitem/sqliteresult.hpp>

namespace sqlitem
{
	void SQliteManager::freeResult( SQliteResult *res )
	{
		delete res;
	}

	SQliteResult *SQliteManager::query( std::string query )
	{
		char *error;

		SQliteResult *res = new SQliteResult( *this );

		if( sqlite_exec( dbh, query.c_str(), &SQliteCallback, res, &error ) != 0 )
		{
			delete res;
			this->error = error;
			free( error );
			return 0;
		}

		return res;
	}

	std::string SQliteManager::addSlashes( std::string text )
	{
		std::string temp;

		// sqlite requires that if you are going to place quotes in a query,
		// you double up the quotes like ""this""
		for( int i = 0; i < text.length(); i++ )
		{
			if( text[i] == '"' ) temp += "\"\"";
			else temp += text[i];
		}

		return temp;
	}

	int SQliteManager::go( std::string query )
	{
		char *error;

		SQliteResult *res = new SQliteResult( *this );

		if( sqlite_exec( dbh, query.c_str(), &SQliteCallback, res, &error ) != 0 )
		{
			delete res;
			this->error = error;
			free( error );
			return -1;
		}

		int rows = res->numRows();
		delete res;

		return rows;
	}

	std::string SQliteManager::lastError()
	{
		std::string err = error;
		error = "";
		return err;
	}

	bool SQliteManager::connect( std::string db )
	{
		char *error;
		dbh = sqlite_open( db.c_str(), 0, &error );
		if( error )
		{
			this->error = error;
			free( error );
			return false;
		}

		connected = true;
		return true;
	}

	void SQliteManager::disconnect()
	{
		connected = false;
		sqlite_close( dbh );
	}
}
